@@ -22,7 +22,7 @@ ngx_os_io_t ngx_os_io = {
     ngx_unix_recv,
     ngx_readv_chain,
     ngx_udp_unix_recv,
-    NULL,
+    ngx_unix_send,
     ngx_writev_chain,
     0
 };
